@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 BEGIN {
-    our $VERSION = '0.13';
+    our $VERSION = '0.14';
 
     require XSLoader;
     XSLoader::load('Math::Int64', $VERSION);
@@ -18,22 +18,27 @@ our @EXPORT_OK = qw(int64
                     native_to_int64 int64_to_native
                     string_to_int64 hex_to_int64
                     int64_to_string int64_to_hex
+                    int64_rand
+                    int64_srand
                     uint64
                     uint64_to_number
                     net_to_uint64 uint64_to_net
                     native_to_uint64 uint64_to_native
                     string_to_uint64 hex_to_uint64
-                    uint64_to_string uint64_to_hex);
+                    uint64_to_string uint64_to_hex
+                    uint64_rand
+                  );
 
 sub import {
     my $pkg = shift;
     my @subs = grep { $_ ne ':native_if_available'} @_;
+    my %native;
     if (@subs != @_ and _backend eq 'IV') {
-	Math::Int64::Native->export_to_level(1, $pkg, @subs);
-    }
-    else {
-	__PACKAGE__->export_to_level(1, $pkg, @subs);
+        $native{$_} = 1 for grep Math::Int64::Native->can($_), @subs;
     }
+    # warn "native: ".join(", ", keys %native);
+    Math::Int64::Native->export_to_level(1, $pkg, grep $native{$_}, @subs);
+    Math::Int64->export_to_level(1, $pkg, grep !$native{$_}, @subs);
 }
 
 use overload ( '+' => \&_add,
@@ -107,17 +112,16 @@ package Math::Int64::Native;
 
 use Carp;
 
-require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = @Math::Int64::EXPORT_OK;
 
-*int64_to_number = \&Math::Int64::int64_to_number;
-*int64_to_net = \&Math::Int64::int64_to_net;
-*int64_to_native = \&Math::Int64::int64_to_native;
+#*int64_to_number = \&Math::Int64::int64_to_number;
+#*int64_to_net = \&Math::Int64::int64_to_net;
+#*int64_to_native = \&Math::Int64::int64_to_native;
 
-*uint64_to_number = \&Math::Int64::int64_to_number;
-*uint64_to_net = \&Math::Int64::uint64_to_net;
-*uint64_to_native = \&Math::Int64::uint64_to_native;
+#*uint64_to_number = \&Math::Int64::int64_to_number;
+#*uint64_to_net = \&Math::Int64::uint64_to_net;
+#*uint64_to_native = \&Math::Int64::uint64_to_native;
 
 1;
 
@@ -226,10 +230,22 @@ Shortcut for string_to_int64($str, 16)
 Converts the int64 value to its string representation in the given
 base (defaults to 10).
 
-=item uint64_to_hex($i64)
+=item int64_to_hex($i64)
 
 Shortcut for C<int64_to_string($i64, 16)>.
 
+=item int64_rand
+
+Generates a 64 bit random number using ISAAC-64 algorithm.
+
+=item int64_srand($seed)
+
+=item int64_srand()
+
+Sets the seed for the random number generator.
+
+C<$seed>, if given, should be a 2KB long string.
+
 =item uint64
 
 =item uint64_to_number
